@@ -61,7 +61,9 @@ TextVisitor::TextVisitor() : positional_(true) {
 }
 
 
-TextVisitor::~TextVisitor() {}
+TextVisitor::~TextVisitor() {
+    delete layout_;
+}
 
 
 void TextVisitor::addToTags(const string& line, const string& entry) {
@@ -127,7 +129,7 @@ void TextVisitor::visit(BasicSceneObject& parent) {
     vector<string>::iterator line = lines_.begin();
     map<string, vector<string> > lines;
     vector<string> lineslist;
-    ;
+
 
     while (line != lines_.end()) {
         lines.insert(make_pair(*line, vector<string>()));
