@@ -26,8 +26,8 @@
 
 
 #include "Data.h"
-#include "DateTime.h"
-#include "Decoder.h"
+#include "MagDateTime.h"
+#include "MagicsDecoder.h"
 #include "EpsBufrAttributes.h"
 #include "UserPoint.h"
 
