@@ -27,7 +27,7 @@
 #define ACCEPT_USE_OF_DEPRECATED_PROJ_API_H 1
 #include <proj_api.h>
 #include "Data.h"
-#include "Decoder.h"
+#include "MagicsDecoder.h"
 #include "GeoPointsDecoderAttributes.h"
 #include "UserPoint.h"
 
